@@ -21,7 +21,7 @@ our @EXPORT_OK = qw(
     shifts      unshifts  once
 );
 
-our $VERSION = '0.34';
+our $VERSION = '0.37';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -29,6 +29,15 @@ use constant ARG_PLACE_HOLDER => {};
 
 sub __ { ARG_PLACE_HOLDER };
 
+sub _has_placeholders {
+    foreach my $arg (@_) {
+        if (ref($arg) and ref(__) and $arg == __) {
+            return 1;
+        }
+    }
+    return 0;
+}
+
 sub noop { return undef }
 
 sub identity {
@@ -108,8 +117,8 @@ sub _is_nonsense_range {
 }
 
 sub get {
-    my $coll    = shift // [];
     my $key     = shift // 0;
+    my $coll    = shift // [];
     my $default = shift;
 
     if (is_array($coll)) {
@@ -488,6 +497,7 @@ sub _get_reduces_args {
 sub partial {
     my $func    = shift;
     my $oldArgs = [@_];
+    my $args_without_placeholders;
 
     if (ref $func ne 'CODE') {
         carp("Expected a function as first argument");
@@ -495,8 +505,12 @@ sub partial {
 
     return sub {
         my $newArgs = [@_];
-        my $no_placeholder_args = _fill_holders($oldArgs, $newArgs);
-        return $func->(@$no_placeholder_args);
+
+        if(!$args_without_placeholders) {
+            $args_without_placeholders = _fill_holders($oldArgs, $newArgs);
+        }
+
+        return $func->(@$args_without_placeholders);
     }
 }
 
@@ -1133,21 +1147,21 @@ Only works one level deep;
         key1 => 'value1',
     };
 
-    get($hash, 'key1');
+    get('key1', $hash);
 
     # 'value1'
 
 
     my $array = [100, 200, 300]
 
-    get($array, 1);
+    get(1, $array);
 
     # 200
 
 
     my $string = "Hello";
 
-    get($string, 1);
+    get(1, $string);
 
     # e
 
@@ -1158,7 +1172,7 @@ Only works one level deep;
         key1 => 'value1',
     };
 
-    get($hash, 'key2', "DEFAULT HERE");
+    get('key2', $hash, "DEFAULT HERE");
 
     # 'DEFAULT HERE'
 
